The application continuously accesses and collects the device's GPS location. GPS tracking is subject to compliance
requirements and is subject to strict restrictions under certain jurisdictions.

GPS tracking may also be abused by malware or attackers who gained access to the device with the permissions of the
application. 
